==> deepend-0.0.1.tar.gz: deepend-0.0.1/README.md <==
# Deepend


<div width="100%" align="center">
    <img alt="GitHub" src="https://img.shields.io/github/license/Letsmoe/deepend?label=License">
    <img alt="GitHub issues" src="https://img.shields.io/github/issues/Letsmoe/deepend?label=Issues">
    <img alt="GitHub contributors" src="https://img.shields.io/github/contributors/Letsmoe/deepend?label=Contributors">
    <img alt="GitHub Repo stars" src="https://img.shields.io/github/stars/Letsmoe/deepend?label=Stars">
    <img alt="GitHub watchers" src="https://img.shields.io/github/watchers/Letsmoe/deepend?label=Watchers">
</div>



<!-- PROJECT LOGO -->
<br />
<div align="center">
  <a href="https://github.com/Letsmoe/deepend">
    <img src="images/logo-light.svg" alt="Logo" width="500" height="250">
  </a>


  <p align="center">
    Deepend is an advanced end-to-end machine learning framework. It offers many <a href="https://continuum-ai.de/doc/deepend/utilities">tools</a>, and <a href="https://continuum-ai.de/doc/deepend/libraries">libraries</a> with a <a href="https://continuum-ai.de/deepend/gui">platform</a> that helps novices gain experience fast and offers researchers and community members all around the globe to publish their work and show their talents.
    <br />
    <a href="https://continuum-ai.de/doc/deepend/"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <a href="https://github.com/Letsmoe/deepend">View Demo</a>
    ·
    <a href="https://github.com/Letsmoe/deepend/issues">Report Bug</a>
    ·
    <a href="https://github.com/Letsmoe/deepend/issues">Request Feature</a>
  </p>
</div>



<!-- TABLE OF CONTENTS -->
<details>
  <summary>Table of Contents</summary>
  <ol>
    <li>
      <a href="#about-the-project">About The Project</a>
      <ul>
        <li><a href="#built-with">Built With</a></li>
      </ul>
    </li>
    <li>
      <a href="#getting-started">Getting Started</a>
      <ul>
        <li><a href="#prerequisites">Prerequisites</a></li>
        <li><a href="#installation">Installation</a></li>
      </ul>
    </li>
    <li><a href="#usage">Usage</a></li>
    <li><a href="#roadmap">Roadmap</a></li>
    <li><a href="#contributing">Contributing</a></li>
    <li><a href="#license">License</a></li>
    <li><a href="#contact">Contact</a></li>
    <li><a href="#acknowledgments">Acknowledgments</a></li>
  </ol>
</details>



<!-- ABOUT THE PROJECT -->
## About The Project

[![Product Name Screen Shot][product-screenshot]](https://example.com)

Here's a blank template to get started: To avoid retyping too much info. Do a search and replace with your text editor for the following: `Letsmoe`, `deepend`, `Continu13798401`, `linkedin_username`, `email`, `email_client`, `Deepend`, `project_description`

<p align="right">(<a href="#top">back to top</a>)</p>


<!-- GETTING STARTED -->
## Getting Started
To start off, open a terminal and add Deepend from your preferred package manager, this will get you up and running in seconds. Deepend comes with some small [datasets](https://github.com/Letsmoe/deepend/main/src/datasets) already preinstalled, we offer you to download many more [from our website](https://continuum-ai.de/deepend/datasets) though and we entice you to take a look at [Kaggle](https://kaggle.com) datasets.

### Dependencies
To run Deepend it is required that you have **NumPy** installed. The utilities module requires you to have **OpenCV** and **os** installed.

### pip
```sh
pip install deepend
```

### Poetry
```sh
poetry add deepend
```

### First Contact

Deepend is both a backend and frontend for creating machine learning models.
Importing it is as simple as any other package. After you installed it from your package manager you can run 
```python
import deepend
```
This will get you everything deepend comes with, to be more specific you can import each module separately. Deepend comes with the following modules:
```python
import deepend.utils as utilities
import deepend.activations as activations
import deepend.models as models
import deepend.losses as losses
import deepend.metrics as metrics
```


<p align="right">(<a href="#top">back to top</a>)</p>


<!-- ROADMAP -->
## Roadmap

- [] LSTM Layers and GRU Cells
- [] N-Dimensional Convolutional Layers

See the [open issues](https://github.com/Letsmoe/deepend/issues) for a full list of proposed features (and known issues).

<p align="right">(<a href="#top">back to top</a>)</p>



<!-- CONTRIBUTING -->
## Contributing

Contributions are what make the open source community such an amazing place to learn, inspire, and create. Any contributions you make are **greatly appreciated**.

If you have a suggestion that would make this better, please fork the repo and create a pull request. You can also simply open an issue with the tag "enhancement".
Don't forget to give the project a star! Thanks again!

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

<p align="right">(<a href="#top">back to top</a>)</p>



<!-- LICENSE -->
## License

Distributed under the MIT License. See `LICENSE.txt` for more information.

<p align="right">(<a href="#top">back to top</a>)</p>



<!-- CONTACT -->
## Contact

Your Name - [@Continu13798401](https://twitter.com/Continu13798401) - info@continuum-ai.de

Project Link: [https://github.com/Letsmoe/deepend](https://github.com/Letsmoe/deepend)

<p align="right">(<a href="#top">back to top</a>)</p>



<!-- ACKNOWLEDGMENTS -->
## Acknowledgments

* []()
* []()
* []()

<p align="right">(<a href="#top">back to top</a>)</p>



<!-- MARKDOWN LINKS & IMAGES -->
<!-- https://www.markdownguide.org/basic-syntax/#reference-style-links -->
[contributors-shield]: https://img.shields.io/github/contributors/Letsmoe/deepend.svg?style=for-the-badge
[contributors-url]: https://github.com/Letsmoe/deepend/graphs/contributors
[forks-shield]: https://img.shields.io/github/forks/Letsmoe/deepend.svg?style=for-the-badge
[forks-url]: https://github.com/Letsmoe/deepend/network/members
[stars-shield]: https://img.shields.io/github/stars/Letsmoe/deepend.svg?style=for-the-badge
[stars-url]: https://github.com/Letsmoe/deepend/stargazers
[issues-shield]: https://img.shields.io/github/issues/Letsmoe/deepend.svg?style=for-the-badge
[issues-url]: https://github.com/Letsmoe/deepend/issues
[license-shield]: https://img.shields.io/github/license/Letsmoe/deepend.svg?style=for-the-badge
[license-url]: https://github.com/Letsmoe/deepend/blob/master/LICENSE.txt
[linkedin-shield]: https://img.shields.io/badge/-LinkedIn-black.svg?style=for-the-badge&logo=linkedin&colorB=555
[linkedin-url]: https://linkedin.com/in/linkedin_username
[product-screenshot]: images/screenshot.png

==> deepend-0.0.2.tar.gz: deepend-0.0.2/README.md <==
# Deepend


<div width="100%" align="center">
    <img alt="GitHub" src="https://img.shields.io/github/license/Letsmoe/deepend?label=License">
    <img alt="GitHub issues" src="https://img.shields.io/github/issues/Letsmoe/deepend?label=Issues">
    <img alt="GitHub contributors" src="https://img.shields.io/github/contributors/Letsmoe/deepend?label=Contributors">
    <img alt="GitHub Repo stars" src="https://img.shields.io/github/stars/Letsmoe/deepend?label=Stars">
    <img alt="GitHub watchers" src="https://img.shields.io/github/watchers/Letsmoe/deepend?label=Watchers">
</div>



<!-- PROJECT LOGO -->
<br />
<div align="center">
  <a href="https://github.com/Letsmoe/deepend">
    <img src="images/logo-light.svg" alt="Logo" width="500" height="250">
  </a>


  <p align="center">
    Deepend is an advanced end-to-end machine learning framework. It offers many <a href="https://continuum-ai.de/doc/deepend/utilities">tools</a>, and <a href="https://continuum-ai.de/doc/deepend/libraries">libraries</a> with a <a href="https://continuum-ai.de/deepend/gui">platform</a> that helps novices gain experience fast and offers researchers and community members all around the globe to publish their work and show their talents.
    <br />
    <a href="https://continuum-ai.de/doc/deepend/"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <a href="https://github.com/Letsmoe/deepend">View Demo</a>
    ·
    <a href="https://github.com/Letsmoe/deepend/issues">Report Bug</a>
    ·
    <a href="https://github.com/Letsmoe/deepend/issues">Request Feature</a>
  </p>
</div>



<!-- TABLE OF CONTENTS -->
<details>
  <summary>Table of Contents</summary>
  <ol>
    <li>
      <a href="#about-the-project">About The Project</a>
      <ul>
        <li><a href="#built-with">Built With</a></li>
      </ul>
    </li>
    <li>
      <a href="#getting-started">Getting Started</a>
      <ul>
        <li><a href="#prerequisites">Prerequisites</a></li>
        <li><a href="#installation">Installation</a></li>
      </ul>
    </li>
    <li><a href="#usage">Usage</a></li>
    <li><a href="#roadmap">Roadmap</a></li>
    <li><a href="#contributing">Contributing</a></li>
    <li><a href="#license">License</a></li>
    <li><a href="#contact">Contact</a></li>
    <li><a href="#acknowledgments">Acknowledgments</a></li>
  </ol>
</details>



<!-- ABOUT THE PROJECT -->
## About The Project

[![Product Name Screen Shot][product-screenshot]](https://example.com)

Here's a blank template to get started: To avoid retyping too much info. Do a search and replace with your text editor for the following: `Letsmoe`, `deepend`, `Continu13798401`, `linkedin_username`, `email`, `email_client`, `Deepend`, `project_description`

<p align="right">(<a href="#top">back to top</a>)</p>


<!-- GETTING STARTED -->
## Getting Started
To start off, open a terminal and add Deepend from your preferred package manager, this will get you up and running in seconds. Deepend comes with some small [datasets](https://github.com/Letsmoe/deepend/main/src/datasets) already preinstalled, we offer you to download many more [from our website](https://continuum-ai.de/deepend/datasets) though and we entice you to take a look at [Kaggle](https://kaggle.com) datasets.

### Dependencies
To run Deepend it is required that you have **NumPy** installed. The utilities module requires you to have **OpenCV** and **os** installed.

### pip
```sh
pip install deepend
```

### First Contact

Deepend is both a backend and frontend for creating machine learning models.
Importing it is as simple as any other package. After you installed it from pip you can run 
```python
import deepend
```
This will get you everything deepend comes with, to be more specific you can import each module separately. Deepend comes with the following modules:
```python
import deepend.utils as utilities
import deepend.activations as activations
import deepend.models as models
import deepend.losses as losses
import deepend.metrics as metrics
```


<p align="right">(<a href="#top">back to top</a>)</p>


<!-- ROADMAP -->
## Roadmap

- [] LSTM Layers and GRU Cells
- [] N-Dimensional Convolutional Layers

See the [open issues](https://github.com/Letsmoe/deepend/issues) for a full list of proposed features (and known issues).

<p align="right">(<a href="#top">back to top</a>)</p>



<!-- CONTRIBUTING -->
## Contributing

Contributions are what make the open source community such an amazing place to learn, inspire, and create. Any contributions you make are **greatly appreciated**.

If you have a suggestion that would make this better, please fork the repo and create a pull request. You can also simply open an issue with the tag "enhancement".
Don't forget to give the project a star! Thanks again!

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

<p align="right">(<a href="#top">back to top</a>)</p>



<!-- LICENSE -->
## License

Distributed under the MIT License. See `LICENSE.txt` for more information.

<p align="right">(<a href="#top">back to top</a>)</p>



<!-- CONTACT -->
## Contact

Your Name - [@Continu13798401](https://twitter.com/Continu13798401) - info@continuum-ai.de

Project Link: [https://github.com/Letsmoe/deepend](https://github.com/Letsmoe/deepend)

<p align="right">(<a href="#top">back to top</a>)</p>



<!-- ACKNOWLEDGMENTS -->
## Acknowledgments

* []()
* []()
* []()

<p align="right">(<a href="#top">back to top</a>)</p>



<!-- MARKDOWN LINKS & IMAGES -->
<!-- https://www.markdownguide.org/basic-syntax/#reference-style-links -->
[contributors-shield]: https://img.shields.io/github/contributors/Letsmoe/deepend.svg?style=for-the-badge
[contributors-url]: https://github.com/Letsmoe/deepend/graphs/contributors
[forks-shield]: https://img.shields.io/github/forks/Letsmoe/deepend.svg?style=for-the-badge
[forks-url]: https://github.com/Letsmoe/deepend/network/members
[stars-shield]: https://img.shields.io/github/stars/Letsmoe/deepend.svg?style=for-the-badge
[stars-url]: https://github.com/Letsmoe/deepend/stargazers
[issues-shield]: https://img.shields.io/github/issues/Letsmoe/deepend.svg?style=for-the-badge
[issues-url]: https://github.com/Letsmoe/deepend/issues
[license-shield]: https://img.shields.io/github/license/Letsmoe/deepend.svg?style=for-the-badge
[license-url]: https://github.com/Letsmoe/deepend/blob/master/LICENSE.txt
[linkedin-shield]: https://img.shields.io/badge/-LinkedIn-black.svg?style=for-the-badge&logo=linkedin&colorB=555
[linkedin-url]: https://linkedin.com/in/linkedin_username
[product-screenshot]: images/screenshot.png
